"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const sinon = require("sinon");
const proxyquire = require("proxyquire");
const ServerTs = {
    Server: sinon.stub(),
};
describe("CLI", () => {
    let cli;
    beforeEach(() => {
        const Cli = proxyquire("./cli", { './server': ServerTs }).Cli;
        cli = new Cli();
    });
    describe("start", () => {
        let serverObject;
        beforeEach(() => {
            serverObject = {
                start: sinon.stub().resolves(),
                addService: sinon.stub().returns(serverObject),
            };
            ServerTs.Server.returns(serverObject);
        });
        describe("without arguments", () => {
            it("should construct and start the server", () => {
                cli.start(["node", "cli.ts", "start"]);
                sinon.assert.calledWith(ServerTs.Server, { dataPath: "./data" });
                sinon.assert.calledWith(serverObject.start);
                sinon.assert.callCount(serverObject.addService, 4);
            });
        });
        describe("with data argument", () => {
            it("should construct and start the server", () => {
                cli.start(["node", "cli.ts", "start", "-d", "/tmp/mydata"]);
                sinon.assert.calledWith(ServerTs.Server, { dataPath: "/tmp/mydata" });
                sinon.assert.calledWith(serverObject.start);
                sinon.assert.callCount(serverObject.addService, 4);
            });
        });
    });
});
//# sourceMappingURL=cli.spec.js.map