"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const SingleProcessDiscovery_1 = require("./SingleProcessDiscovery");
class TestService {
}
TestService.baseRoute = "/test";
class FooService {
    constructor(tags) {
        this.tags = tags;
    }
}
FooService.baseRoute = "/foo";
describe("SingleProcessDiscovery", () => {
    let discovery;
    beforeEach(() => {
        discovery = new SingleProcessDiscovery_1.SingleProcessDiscovery();
    });
    describe("registerService", () => {
        let fooMasterService;
        beforeEach(() => {
            fooMasterService = new FooService(['master']);
        });
        describe("with tags", () => __awaiter(this, void 0, void 0, function* () {
            beforeEach(() => __awaiter(this, void 0, void 0, function* () {
                yield discovery.registerService(fooMasterService, "127.0.0.1", 9080);
            }));
            it("find with matching tags should return a handle", () => __awaiter(this, void 0, void 0, function* () {
                const handle = yield discovery.find("FooService", ['master']);
                chai_1.assert.isDefined(handle);
            }));
            it("find with non-matching tags should not return a handle", () => __awaiter(this, void 0, void 0, function* () {
                const handle = yield discovery.find("FooService", ['slave']);
                chai_1.assert.isUndefined(handle);
            }));
            it("find with no tags should return a handle", () => __awaiter(this, void 0, void 0, function* () {
                const handle = yield discovery.find("FooService");
                chai_1.assert.isDefined(handle);
            }));
        }));
    });
    describe("find", () => {
        let mockService;
        beforeEach(() => __awaiter(this, void 0, void 0, function* () {
            mockService = new TestService();
            yield discovery.registerService(mockService, "127.0.0.1", 9080);
        }));
        it("should find the TestService", () => __awaiter(this, void 0, void 0, function* () {
            const result = yield discovery.find("TestService");
            chai_1.assert.equal(result.name, "TestService");
            chai_1.assert.equal(result.serviceUrl, "http://127.0.0.1:9080/test");
        }));
        it("should not find the DummyService", () => __awaiter(this, void 0, void 0, function* () {
            const result = yield discovery.find("DummyService");
            chai_1.assert.isUndefined(result);
        }));
    });
    describe("findAll", () => {
        let mockService;
        beforeEach(() => __awaiter(this, void 0, void 0, function* () {
            mockService = new TestService();
            yield discovery.registerService(mockService, "127.0.0.1", 9080);
        }));
        it("should find all TestServices", () => __awaiter(this, void 0, void 0, function* () {
            const result = yield discovery.findAll("TestService");
            chai_1.assert.isArray(result);
            chai_1.assert.equal(result.length, 1);
        }));
        it("should not find any DummyServices", () => __awaiter(this, void 0, void 0, function* () {
            const result = yield discovery.findAll("DummyService");
            chai_1.assert.isArray(result);
            chai_1.assert.equal(result.length, 0);
        }));
    });
    describe("unregisterService", () => {
        let mockService;
        beforeEach(() => __awaiter(this, void 0, void 0, function* () {
            mockService = new TestService();
            yield discovery.registerService(mockService, "127.0.0.1", 9080);
        }));
        it("should remove a service", () => __awaiter(this, void 0, void 0, function* () {
            yield discovery.unregisterService(mockService);
            const result = yield discovery.findAll('TestService');
            chai_1.assert.isArray(result);
            chai_1.assert.equal(result.length, 0);
        }));
    });
});
//# sourceMappingURL=SingleProcessDiscovery.spec.js.map