/// <reference types="node" />
/// <reference types="express" />
import { Discovery } from './discovery/discovery';
import { Logger } from './logger';
import * as Express from 'express';
import * as http from 'http';
import { EventEmitter } from 'events';
export declare class ServerConfiguration {
    serverId?: string;
    hostname?: string;
    port?: number;
    agreement?: string | {
        name: string;
        email: string;
    };
    logLevel?: string;
    logPath?: string;
    logger?: Logger;
    discovery?: Discovery;
    keysPaths?: {
        publicKeyPath: string;
        privateKeyPath: string;
    };
    dataPath?: string;
}
export declare class Server extends EventEmitter {
    config: ServerConfiguration;
    services: any[];
    discovery: Discovery;
    logger: Logger;
    version: string;
    private websocketRoutes;
    private _started;
    readonly started: boolean;
    readonly expressApp: Express.Application;
    readonly httpServer: http.Server;
    constructor(config?: ServerConfiguration);
    useMiddleware(...args: any[]): Server;
    start(): Promise<void>;
    shutdown(): Promise<void>;
    addService(service: any | string, config?: object): this;
    removeService(service: any | string): this;
    attemptAddServiceEndpoints(service: any): this;
    private upgradeHandler(req, socket, head);
}
