"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = require("chai");
const path = require("path");
const portfinder = require("portfinder");
const tmp = require("tmp");
const SyncService_1 = require("./SyncService");
const server_1 = require("../server");
describe('SyncService', () => {
    let service;
    let server;
    let tmpDir;
    beforeEach(() => {
        tmpDir = tmp.dirSync();
    });
    afterEach(() => __awaiter(this, void 0, void 0, function* () {
        if (server) {
            yield server.shutdown();
        }
    }));
    describe("with minimal configuration", () => {
        it("should use default address and an ephemeral port", () => __awaiter(this, void 0, void 0, function* () {
            server = new server_1.Server();
            service = new SyncService_1.SyncService({
                dataPath: path.resolve(tmpDir.name, "sync"),
                publicKeyPath: path.resolve(process.cwd(), "data/keys/auth.pub")
            });
            server.addService(service);
            yield server.start();
            const address = service.address();
            chai_1.assert.equal(address.address, "127.0.0.1");
            chai_1.assert.isAtLeast(address.port, 32768);
            chai_1.assert.isAtMost(address.port, 65535);
        }));
    });
    describe("with configured address and port", () => {
        it("should use supplied address and port", () => __awaiter(this, void 0, void 0, function* () {
            const port = yield portfinder.getPortPromise();
            server = new server_1.Server();
            service = new SyncService_1.SyncService({
                dataPath: path.join(tmpDir.name, "sync"),
                publicKeyPath: path.resolve(process.cwd(), "data/keys/auth.pub"),
                listenAddress: "0.0.0.0",
                listenPort: port,
            });
            server.addService(service);
            yield server.start();
            const address = service.address();
            chai_1.assert.equal(address.address, "0.0.0.0");
            chai_1.assert.equal(address.port, port);
        }));
    });
});
//# sourceMappingURL=SyncService.spec.js.map