"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const Realm = require("realm");
const fs = require("fs-extra");
const path = require("path");
const moment = require("moment");
const discovery_1 = require("../../discovery");
const decorators_1 = require("../../decorators");
const superagent = require("superagent");
const URI = require("urijs");
const shared_1 = require("../../shared");
let userSchema = {
    name: 'User',
    primaryKey: 'userId',
    properties: {
        userId: 'string',
        isAdmin: { type: 'bool', optional: false },
        metadata: { type: 'list', objectType: 'UserMetadata' }
    }
};
let metadataSchema = {
    name: 'UserMetadata',
    properties: {
        userId: 'string',
        key: 'string',
        value: { type: 'string', optional: true }
    }
};
class AuthService {
    constructor(config = {}) {
        this.config = config;
        if (!this.config.privateKeyPath) {
            this.config.privateKeyPath = path.resolve(process.cwd(), 'data/keys/auth.key');
        }
    }
    authenticateOrCreateUser(body) {
        return __awaiter(this, void 0, void 0, function* () {
            throw new Error('You must implement the authenticate method in your subclass');
        });
    }
    start(discovery) {
        return __awaiter(this, void 0, void 0, function* () {
            this.discovery = discovery;
            this.realm = new Realm({ path: './data/auth.realm', schema: [userSchema, metadataSchema] });
            this.privateKey = yield fs.readFile(this.config.privateKeyPath)
                .then(data => data.toString());
        });
    }
    authenticate(request) {
        return __awaiter(this, void 0, void 0, function* () {
            if (request.body.path !== undefined) {
                let realmManagementServiceHandle = yield this.discovery.find('realms');
                if (!realmManagementServiceHandle.serviceUrl)
                    throw new Error('Unable to contact the Realms service');
                const accessTokenUrl = new URI(realmManagementServiceHandle.serviceUrl).segment('/access_token').toString();
                const response = yield superagent.post(accessTokenUrl)
                    .send(request.body);
                return response.body;
            }
            const app_id = request.body["app_id"] || 'io.realm.Auth';
            const authResponse = yield this.authenticateOrCreateUser(request.body);
            const authToken = shared_1.signToken({ user_id: authResponse.userId, is_admin: authResponse.isAdmin }, this.privateKey);
            let expires = moment().add('m', 10).unix();
            let json = {
                refresh_token: {
                    token: authToken,
                    token_data: {
                        app_id: app_id,
                        identity: authResponse.userId,
                        is_admin: authResponse.isAdmin,
                        access: ["refresh"],
                        expires: expires
                    }
                }
            };
            return json;
        });
    }
    getUser(userId) {
        const foundUser = this.realm.objectForPrimaryKey('User', userId);
        return foundUser;
    }
    getUserMetadata(userId) {
        let userMetadata = {};
        this.realm.objects('UserMetadata').filtered('userId = $0', userId).forEach((meta) => {
            userMetadata[meta.key] = meta.value;
        });
        return userMetadata;
    }
    storeUser(userId, isAdmin, metadata) {
        this.realm.write(() => {
            this.realm.create('User', { userId: userId, isAdmin: isAdmin }, true);
            if (metadata) {
                for (let key in metadata) {
                    this.realm.create('UserMetadata', {
                        userId: userId,
                        key: key,
                        value: metadata[key]
                    }, true);
                }
            }
        });
        return { userId: userId, isAdmin: isAdmin, metadata: this.getUserMetadata(userId) };
    }
}
__decorate([
    decorators_1.Start(),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [discovery_1.Discovery]),
    __metadata("design:returntype", Promise)
], AuthService.prototype, "start", null);
__decorate([
    decorators_1.Post('/'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object]),
    __metadata("design:returntype", Promise)
], AuthService.prototype, "authenticate", null);
exports.AuthService = AuthService;
//# sourceMappingURL=authservice.js.map