"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const CircularBuffer = require("circular-buffer");
const logger_1 = require("../../logger");
const decorators_1 = require("../../decorators");
let LogService = class LogService {
    constructor() {
        this.logger = new logger_1.Mute();
        this.rootLogger = new logger_1.Mute();
        this.buffers = {};
        for (let level in logger_1.levels) {
            this.buffers[level] = new CircularBuffer(1000);
        }
    }
    showLogs(level) {
        const buf = this.buffers[level];
        if (buf) {
            return buf.toarray();
        }
    }
    setRootLogger(l) {
        this.rootLogger = l;
    }
    setLogger(l) {
        this.logger = l;
    }
    message(level, msg, ctx) {
        for (let blevel in this.buffers) {
            if (logger_1.levels[blevel] >= logger_1.levels[level]) {
                const timestampedCtx = Object.assign({}, ctx, { timestamp: new Date() });
                this.buffers[blevel].enq({ level, msg, ctx: timestampedCtx });
            }
        }
    }
    start() {
        return __awaiter(this, void 0, void 0, function* () {
            this.listener = this.message.bind(this);
            this.rootLogger.on('message', this.listener);
        });
    }
    stop() {
        return __awaiter(this, void 0, void 0, function* () {
            this.rootLogger.removeListener('message', this.listener);
        });
    }
};
__decorate([
    decorators_1.Get('/:level'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String]),
    __metadata("design:returntype", void 0)
], LogService.prototype, "showLogs", null);
__decorate([
    decorators_1.Unmute(false),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [logger_1.Logger]),
    __metadata("design:returntype", void 0)
], LogService.prototype, "setRootLogger", null);
__decorate([
    decorators_1.Unmute(),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [logger_1.Logger]),
    __metadata("design:returntype", void 0)
], LogService.prototype, "setLogger", null);
__decorate([
    decorators_1.Start(),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Promise)
], LogService.prototype, "start", null);
__decorate([
    decorators_1.Stop(),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", Promise)
], LogService.prototype, "stop", null);
LogService = __decorate([
    decorators_1.BaseRoute('/log'),
    decorators_1.ServiceName('log'),
    __metadata("design:paramtypes", [])
], LogService);
exports.LogService = LogService;
//# sourceMappingURL=logservice.js.map